@@ -1,4 +1,5 @@
-use core::option::Option::{self, Some};
+#[cfg(not(feature = "std"))] use core::option::Option::{self, Some};
+
 use core::{mem, ptr};
 
 use crate::{Cast, Endian, Flip};
@@ -6,7 +7,7 @@ use crate::{Cast, Endian, Flip};
 
 
 ///
-/// Defines methods to `decast` and `Flip` on memory.
+/// Defines methods to `decast` and `endian-flip` on memory.
 ///
 /// Note: In this crate, the term `encast` means decoding a number of
 /// bytes to one or more values, the term `decast` means encoding one
@@ -62,8 +63,7 @@ use crate::{Cast, Endian, Flip};
 /// argument.  The methods whose name contain 's' (= slice) or 'v' (=
 /// vector) `decast` to a series of structured binary data.  The
 /// methods whose names end with 'f' flip the endianness of the
-/// results.  Currently, only an implementation for `[u8]` is
-/// provided.
+/// results.  Currently, an implementation for `[u8]` is provided.
 ///
 /// The size of `self` should be larger than or equal to the specified
 /// number of value(s) of the specified type `T`.  If there is enough
@@ -110,7 +110,7 @@ pub trait DecastMem {
     /// them at the head of `self`.  The endianness of the resulting
     /// bytes is not flipped.
     /// (This method is replaced by `decasts`)
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn decastv<T>(&mut self, slice: &[T]) -> Option<usize>
     where
 	T: Cast;
@@ -120,7 +120,7 @@ pub trait DecastMem {
     /// bytes is flipped if necessary.  The endianness of the
     /// resulting bytes is specified in `endian`.
     /// (This method is replaced by `decastsf`)
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn decastvf<T>(&mut self, slice: &[T], endian: Endian) -> Option<usize>
     where
 	T: Cast + Flip;
@@ -136,9 +136,9 @@ impl DecastMem for [u8]
 	let bytes = self.get_mut(0 .. mem::size_of::<T>())?;
 
 	unsafe {
-	    ptr::copy_nonoverlapping(val_ptr as *const T as *const u8,
-				     bytes.as_mut_ptr(),
-				     mem::size_of::<T>());
+	    ptr::copy_nonoverlapping::<u8>(val_ptr as *const T as *const u8,
+					   bytes.as_mut_ptr(),
+					   mem::size_of::<T>());
 	}
 
 	Some(mem::size_of::<T>())
@@ -155,9 +155,9 @@ impl DecastMem for [u8]
 	T: Cast + Flip
     {
 	if !endian.need_swap() {
-	    self.decast(val_ptr)
+	    self.decast::<T>(val_ptr)
 	} else {
-	    self.decast(&val_ptr.flip_val_swapped())
+	    self.decast::<T>(&val_ptr.flip_val_swapped())
 	}
     }
 
@@ -168,9 +168,9 @@ impl DecastMem for [u8]
 	let bytes = self.get_mut(0 .. mem::size_of::<T>() * slice.len())?;
 
 	unsafe {
-	    ptr::copy_nonoverlapping(slice.as_ptr() as *const u8,
-				     bytes.as_mut_ptr(),
-				     bytes.len());
+	    ptr::copy_nonoverlapping::<u8>(slice.as_ptr() as *const u8,
+					   bytes.as_mut_ptr(),
+					   bytes.len());
 	}
 
 	Some(bytes.len())
@@ -181,31 +181,31 @@ impl DecastMem for [u8]
 	T: Cast + Flip
     {
 	if !endian.need_swap() {
-	    self.decasts(slice)
+	    self.decasts::<T>(slice)
 	} else {
 	    let bytes = self.get_mut(0 .. mem::size_of::<T>() * slice.len())?;
 	    let mut off = 0;
 	    for elem in slice {
-		bytes[off ..].decast(&elem.flip_val_swapped())?;
+		bytes[off ..].decast::<T>(&elem.flip_val_swapped())?;
 		off += mem::size_of::<T>();
 	    }
 	    Some(off)
 	}
     }
 
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn decastv<T>(&mut self, slice: &[T]) -> Option<usize>
     where
 	T: Cast
     {
-	self.decasts(slice)
+	self.decasts::<T>(slice)
     }
 
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn decastvf<T>(&mut self, slice: &[T], endian: Endian) -> Option<usize>
     where
 	T: Cast + Flip
     {
-	self.decastsf(slice, endian)
+	self.decastsf::<T>(slice, endian)
     }
 }
