@@ -1,14 +1,15 @@
 use core::mem::MaybeUninit;
 use core::mem;
 use std::io::{Read, Result};
+#[cfg(doc)] use std::io;
 
 use crate::{Cast, Endian, Flip};
-use crate::experimental::{AsifBytes, FlipUnsized};
+use crate::experimental::AsifBytes;
 #[cfg(doc)] use crate::BE;
 
 
 ///
-/// Defines methods to `encast` and `Flip` through `io::Read`.
+/// Defines methods to `encast` and `endian-flip` through [`io::Read`].
 ///
 /// Note: In this crate, the term `encast` means decoding a number of
 /// bytes to one or more values, the term `decast` means encoding one
@@ -66,16 +67,16 @@ use crate::experimental::{AsifBytes, FlipUnsized};
 /// compiler can infer it.  The methods whose name contain 's' (=
 /// slice) or 'v' (= vector) `encast` a series of structured binary
 /// data.  The methods whose names end with 'f' flip the endianness of
-/// the results.  Currently, only an implementation for trait
-/// `std::io::Read` is provided.
+/// the results.  Currently, an implementation for trait [`io::Read`]
+/// is provided.
 ///
 /// The input `self` should have enough bytes to decode to the
 /// specified number of value(s) of the specified type `T`.  If there
 /// are enough bytes, the required number of bytes are read from I/O
 /// and decoded to the specified type of value(s).  The remaining
 /// bytes in input `self` are untouched.  If successful, return value
-/// is enclosed in `Ok`().  If failed, `Err`(`std::io::Error`) is
-/// returned.
+/// is enclosed in `Ok`().  If failed, `Err`([`io::Error`]) is
+/// returned.  The type of the return value is [`io::Result`].
 ///
 /// When argument `endian` is specified, the endianness of value(s) is
 /// flipped if necessary.
@@ -197,7 +198,7 @@ where
     where
 	T: Cast + Flip
     {
-	let mut val: T = self.encast()?;
+	let mut val = self.encast::<T>()?;
 	val.flip_var(endian);
 	Ok(val)
     }
@@ -216,8 +217,10 @@ where
     where
 	T: Cast + Flip
     {
-	let size = self.encasts(slice)?;
-	slice.flip_var(endian);
+	let size = self.encasts::<T>(slice)?;
+	for elem in slice {
+	    elem.flip_var(endian);
+	}
 	Ok(size)
     }
 
@@ -235,8 +238,10 @@ where
     where
 	T: Cast + Flip
     {
-	let mut vec = self.encastv(nelem)?;
-	vec.flip_var(endian);
+	let mut vec = self.encastv::<T>(nelem)?;
+	for elem in &mut vec {
+	    elem.flip_var(endian);
+	}
 	Ok(vec)
     }
 }
@@ -251,6 +256,7 @@ where
 // (2) Section "Relationship with ManuallyDrop" of mem::forget at
 // https://doc.rust-lang.org/stable/std/mem/fn.forget.html#relationship-with-manuallydrop
 //
+#[inline]
 unsafe fn new_vec<T, F>(nelem: usize, mut fill_new_slice: F) -> Result<Vec<T>>
 where
     T: Cast,
