@@ -1,14 +1,16 @@
-use core::option::Option::{self, Some};
+#[cfg(not(feature = "std"))] use core::option::Option::{self, Some};
+#[cfg(feature = "alloc")] extern crate alloc;
+#[cfg(feature = "alloc")] use alloc::vec::Vec;
+
 use core::mem::MaybeUninit;
 use core::{mem, ptr};
 
 use crate::{Cast, Endian, Flip};
-use crate::experimental::FlipUnsized;
 #[cfg(doc)] use crate::BE;
 
 
 ///
-/// Defines methods to `encast` and `Flip` on memory.
+/// Defines methods to `encast` and `endian-flip` on memory.
 ///
 /// Note: In this crate, the term `encast` means decoding a number of
 /// bytes to one or more values, the term `decast` means encoding one
@@ -61,8 +63,7 @@ use crate::experimental::FlipUnsized;
 /// compiler can infer it.  The methods whose name contain 's' (=
 /// slice) or 'v' (= vector) `encast` a series of structured binary
 /// data.  The methods whose names end with 'f' flip the endianness of
-/// the results.  Currently, only an implementation for `[u8]` is
-/// provided.
+/// the results.  Currently, an implementation for `[u8]` is provided.
 ///
 /// The size of `self` should be larger than or equal to the specified
 /// number of value(s) of the specified type `T`.  If there are enough
@@ -111,7 +112,7 @@ pub trait EncastMem {
     /// value(s) of type `T` and returns the vector.  The endianness
     /// of the resulting value(s) is not flipped.  The number of
     /// elements in the resulting vecotr is specified in `nelem`.
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn encastv<T>(&self, nelem: usize) -> Option<Vec<T>>
     where
 	T: Cast;
@@ -121,7 +122,7 @@ pub trait EncastMem {
     /// of the resulting value(s) is flipped if necessary.  The
     /// endianness of the bytes is specified in `endian`.  The number
     /// of elements in the resulting vecotr is specified in `nelem`.
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn encastvf<T>(&self, nelem: usize, endian: Endian) -> Option<Vec<T>>
     where
 	T: Cast + Flip;
@@ -139,9 +140,9 @@ impl EncastMem for [u8]
 	// Decode a value of type T from `bytes`.
 	let mut val = MaybeUninit::<T>::uninit();
 	unsafe {
-	    ptr::copy_nonoverlapping(bytes.as_ptr(),
-				     val.as_mut_ptr() as *mut u8,
-				     mem::size_of::<T>());
+	    ptr::copy_nonoverlapping::<u8>(bytes.as_ptr(),
+					   val.as_mut_ptr() as *mut u8,
+					   mem::size_of::<T>());
 	    Some(val.assume_init())
 	}
 
@@ -155,7 +156,7 @@ impl EncastMem for [u8]
     where
 	T: Cast + Flip
     {
-	let mut val: T = self.encast()?;
+	let mut val = self.encast::<T>()?;
 	val.flip_var(endian);
 	Some(val)
     }
@@ -167,9 +168,9 @@ impl EncastMem for [u8]
 	let bytes = self.get(0 .. mem::size_of::<T>() * slice.len())?;
 
 	unsafe {
-	    ptr::copy_nonoverlapping(bytes.as_ptr(),
-				     slice.as_mut_ptr() as *mut u8,
-				     bytes.len());
+	    ptr::copy_nonoverlapping::<u8>(bytes.as_ptr(),
+					   slice.as_mut_ptr() as *mut u8,
+					   bytes.len());
 	}
 
 	Some(bytes.len())
@@ -179,12 +180,14 @@ impl EncastMem for [u8]
     where
 	T: Cast + Flip
     {
-	let size = self.encasts(slice)?;
-	slice.flip_var(endian);
+	let size = self.encasts::<T>(slice)?;
+	for elem in slice {
+	    elem.flip_var(endian);
+	}
 	Some(size)
     }
 
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn encastv<T>(&self, nelem: usize) -> Option<Vec<T>>
     where
 	T: Cast
@@ -195,13 +198,15 @@ impl EncastMem for [u8]
 	}
     }
 
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn encastvf<T>(&self, nelem: usize, endian: Endian) -> Option<Vec<T>>
     where
 	T: Cast + Flip
     {
-	let mut vec = self.encastv(nelem)?;
-	vec.flip_var(endian);
+	let mut vec = self.encastv::<T>(nelem)?;
+	for elem in &mut vec {
+	    elem.flip_var(endian);
+	}
 	Some(vec)
     }
 }
@@ -216,7 +221,8 @@ impl EncastMem for [u8]
 // (2) Section "Relationship with ManuallyDrop" of mem::forget at
 // https://doc.rust-lang.org/stable/std/mem/fn.forget.html#relationship-with-manuallydrop
 //
-#[cfg(feature = "std")]
+#[inline]
+#[cfg(feature = "alloc")]
 unsafe fn new_vec<T, F>(nelem: usize, fill_new_slice: F) -> Option<Vec<T>>
 where
     T: Cast,
