@@ -1,4 +1,6 @@
-use core::option::Option;
+#[cfg(not(feature = "std"))] use core::option::Option;
+#[cfg(feature = "alloc")] extern crate alloc;
+#[cfg(feature = "alloc")] use alloc::vec::Vec;
 
 use crate::{Cast, EncastMem, Endian, Flip};
 #[cfg(doc)] use crate::BE;
@@ -56,8 +58,7 @@ use crate::{Cast, EncastMem, Endian, Flip};
 /// the memory to one or more values of the specified type.  The
 /// methods whose name contain 's' (= slice) or 'v' (= vector)
 /// `encast` a series of structured binary data.  The methods whose
-/// names end with 'f' flip the endianness of the results.  Currently,
-/// only an implementation for `[u8]` is provided.
+/// names end with 'f' flip the endianness of the results.
 ///
 /// The bytes in argument `bytes` should be larger than or equal to
 /// the specified number of value(s) of the specified type `T`.  If
@@ -106,7 +107,7 @@ pub trait EncastArg: Cast {
     /// value(s) of type `T` and returns the vector.  The endianness
     /// of the resulting value(s) is not flipped.  The number of
     /// elements in the resulting vecotr is specified in `nelem`.
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn encastv(bytes: &[u8], nelem: usize) -> Option<Vec<Self>>;
 
     /// Decodes the bytes at the head of `bytes` to a vector of
@@ -114,7 +115,7 @@ pub trait EncastArg: Cast {
     /// of the resulting value(s) is flipped if necessary.  The
     /// endianness of the bytes is specified in `endian`.  The number
     /// of elements in the resulting vecotr is specified in `nelem`.
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn encastvf(bytes: &[u8], nelem: usize, endian: Endian)
 		-> Option<Vec<Self>>
     where
@@ -128,19 +129,19 @@ where
 {
     fn encast(bytes: &[u8]) -> Option<Self>
     {
-	bytes.encast()
+	bytes.encast::<Self>()
     }
 
     fn encastf(bytes: &[u8], endian: Endian) -> Option<Self>
     where
 	Self: Flip
     {
-	bytes.encastf(endian)
+	bytes.encastf::<Self>(endian)
     }
 
     fn encasts(bytes: &[u8], slice: &mut [Self]) -> Option<usize>
     {
-	bytes.encasts(slice)
+	bytes.encasts::<Self>(slice)
     }
 
     fn encastsf(bytes: &[u8], slice: &mut [Self], endian: Endian)
@@ -148,21 +149,21 @@ where
     where
 	Self: Flip
     {
-	bytes.encastsf(slice, endian)
+	bytes.encastsf::<Self>(slice, endian)
     }
 
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn encastv(bytes: &[u8], nelem: usize) -> Option<Vec<Self>>
     {
-	bytes.encastv(nelem)
+	bytes.encastv::<Self>(nelem)
     }
 
-    #[cfg(feature = "std")]
+    #[cfg(feature = "alloc")]
     fn encastvf(bytes: &[u8], nelem: usize, endian: Endian)
 		-> Option<Vec<Self>>
     where
 	Self: Flip
     {
-	bytes.encastvf(nelem, endian)
+	bytes.encastvf::<Self>(nelem, endian)
     }
 }
